@@ -1,5 +1,6 @@
 from .base import AlgoHashRateType
 from .blake256 import Blake256HashRate
+from .blockflow import BlockFlowHashRate
 from .eaglesong import EaglesongHashRate
 from .equihash import EquihashHashRate
 from .ethash import EtHashHashRate
@@ -9,6 +10,7 @@ from .kheavyhash import KHeavyHashHashRate
 from .scrypt import ScryptHashRate
 from .sha256 import SHA256HashRate
 from .x11 import X11HashRate
+from .zksnark import ZkSnarkHashRate
 
 
 class AlgoHashRate:
@@ -22,3 +24,5 @@ class AlgoHashRate:
     EAGLESONG = EaglesongHashRate
     ETHASH = EtHashHashRate
     EQUIHASH = EquihashHashRate
+    BLOCKFLOW = BlockFlowHashRate
+    ZKSNARK = ZkSnarkHashRate
