@@ -25,7 +25,9 @@ from pyasic.miners.device.models import (
     S19i,
     S19j,
     S19jNoPIC,
+    S19jPlus,
     S19jPro,
+    S19jProPlus,
     S19jXP,
     S19KPro,
     S19Plus,
@@ -80,6 +82,10 @@ class BMMinerS19jPro(AntminerModern, S19jPro):
     pass
 
 
+class BMMinerS19jPlus(AntminerModern, S19jPlus):
+    pass
+
+
 class BMMinerS19L(AntminerModern, S19L):
     pass
 
@@ -102,3 +108,7 @@ class BMMinerS19KPro(AntminerModern, S19KPro):
 
 class BMMinerS19jXP(AntminerModern, S19jXP):
     pass
+
+
+class BMMinerS19jProPlus(AntminerModern, S19jProPlus):
+    pass
