@@ -14,4 +14,6 @@
 #  limitations under the License.                                              -
 # ------------------------------------------------------------------------------
 from .HS3 import BMMinerHS3
+from .KA3 import BMMinerKA3
+from .KS3 import BMMinerKS3
 from .L3 import BMMinerL3Plus
