@@ -15,10 +15,8 @@
 # ------------------------------------------------------------------------------
 
 from pyasic.miners.backends import AntminerOld
-from pyasic.miners.types import DR5
+from pyasic.miners.device.models import DR5
 
 
 class CGMinerDR5(AntminerOld, DR5):
-    def __init__(self, ip: str, api_ver: str = "0.0.0"):
-        super().__init__(ip, api_ver)
-        self.supports_shutdown = False
+    supports_shutdown = False
